<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:exsl="http://exslt.org/common" 
                xmlns:func="http://exslt.org/functions"
                xmlns:dyn="http://exslt.org/dynamic"
                xmlns:math="http://exslt.org/math"
                xmlns:str="http://exslt.org/strings"
                xmlns:g="."
                xmlns:galleroo="."
                extension-element-prefixes="dyn func exsl math str g galleroo" 
                version='1.1'>
<xsl:include href="../Lib/galleroo.xsl" />

<xsl:output method="html" /> 

<!-- doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" indent="yes" -->

<!-- Galleroo Tavla XSL XML->HTML stylesheet 1.2
     Copyright 2003-2004, all rights reserved, xyster.net
     written: 	5/7/03
     modified:  2/11/03
     author: 	xyster

     comments: 	
-->

<xsl:param name="rows-per-index">3</xsl:param>
<xsl:param name="columns-per-index">4</xsl:param>
<xsl:param name="title">Photo Gallery</xsl:param>
<xsl:param name="sub-title" />
<xsl:param name="text-color">#000000</xsl:param>
<xsl:param name="background-color">#FFFFFF</xsl:param>
<xsl:param name="link-color">#0000FF</xsl:param>
<xsl:param name="visited-link-color">#800080</xsl:param>
<xsl:param name="active-link-color">#FF0000</xsl:param>
<xsl:param name="previous-image">previous.gif</xsl:param>
<xsl:param name="next-image">next.gif</xsl:param>
<xsl:param name="home-image">home.gif</xsl:param>
<xsl:param name="blank-image">blank.gif</xsl:param>
<xsl:param name="sort-by">date</xsl:param>
<xsl:param name="thumb-size">75</xsl:param>
<xsl:param name="do-three-stage">no</xsl:param>
<xsl:param name="html-file-prefix" />
<xsl:param name="do-auto-play-movies">no</xsl:param>
<xsl:param name="background-image" />
<xsl:param name="do-thumb-slider">no</xsl:param>
<xsl:param name="custom-css-file" />
<xsl:param name="font" />

<xsl:variable name="thumbs-per-index" select="$rows-per-index * $columns-per-index" />

<xsl:template match="list">

    <!-- yummy! copy over the pix to a new *sorted* list
    -->
    <xsl:variable name="sorted-pix" select="galleroo:sort-pix(media/object/children/object/children/object, $sort-by)" />

    <!-- css -->
    <xsl:call-template name="gal-emit-css-file">
        <xsl:with-param name="name" select="'index'" />
        <xsl:with-param name="html-file-prefix" select="$html-file-prefix" />
        <xsl:with-param name="background-image" select="$background-image" />
        <xsl:with-param name="background-color" select="$background-color" />
        <xsl:with-param name="font" select="$font" />
        <xsl:with-param name="text-color" select="$text-color" />
        <xsl:with-param name="link-color" select="$link-color" />
        <xsl:with-param name="active-link-color" select="$active-link-color" />
        <xsl:with-param name="visited-link-color" select="$visited-link-color" />
    </xsl:call-template>
    
    <!-- gallery -->
    <xsl:for-each select="exsl:node-set($sorted-pix)/*[position() mod $thumbs-per-index = 1]">
        <xsl:call-template name="index">
            <xsl:with-param name="pix" select="following-sibling::object[position() &lt; $thumbs-per-index] | self::object" />
            <xsl:with-param name="index-index" select="position()" />
            <xsl:with-param name="index-last" select="last()" />
        </xsl:call-template>
    </xsl:for-each>

</xsl:template>

<xsl:template name="index">
    <xsl:param name="pix" />
    <xsl:param name="index-index" />
    <xsl:param name="index-last" />
    <html>
        <xsl:comment> Transformed from XML with Galleroo Tavla XSL stylesheet 1.2 </xsl:comment>
        <xsl:comment> Source path='<xsl:value-of select="$source-root/list/media/basepath" />' </xsl:comment>
    <head>
    <link type="text/css" rel="stylesheet" href="{$html-file-prefix}index.css" />
    <xsl:if test="string-length($custom-css-file) != 0">
        <link type="text/css" rel="stylesheet" href="{$custom-css-file}" />
    </xsl:if>    

    <title><xsl:value-of select="$title" /> - <xsl:value-of select="$sub-title" /> (page <xsl:value-of select="$index-index" /> of <xsl:value-of select="$index-last" />)</title>
    </head>
    <body class="index-page">

    <!-- title -->
    <div align="center"><h1><xsl:value-of select="$title" /></h1></div>
    
    <!-- subtitle -->
    <div align="center"><h3><xsl:value-of select="$sub-title" /></h3></div> 
        
    <!-- navigation bar -->
    <div>
    <table align="center" border="0">
    <tr>
        <!-- previous -->
        <td>
        <xsl:choose>
            <xsl:when test="$index-index = 1">
                <img src="{$blank-image}" border="0" />
            </xsl:when>
            <xsl:otherwise>
                <a href="{$html-file-prefix}{galleroo:index-html-name($index-index - 1)}"><img src="{$previous-image}" border="0" /></a>
            </xsl:otherwise>
        </xsl:choose>    
       </td>
       <!-- home -->
       <td>
       <a href="../index.html"><img src="{$home-image}" border="0" /></a>
       </td>
       <!-- next -->
       <td>
         <xsl:choose>
            <xsl:when test="$index-index = $index-last">
                <img src="{$blank-image}" border="0" />
            </xsl:when>
            <xsl:otherwise>
                <a href="{$html-file-prefix}{galleroo:index-html-name($index-index + 1)}"><img src="{$next-image}" border="0" /></a>
            </xsl:otherwise>
         </xsl:choose>
       </td>
    </tr>
    <!-- page index -->
    <tr>
    <td align="center" colspan="3">
     page <xsl:value-of select="$index-index" /> of <xsl:value-of select="$index-last" />
    </td>
    </tr>
    </table>
    </div>
    
    <!-- thumbnail table -->
    <div>
    <xsl:call-template name="table">
        <xsl:with-param name="pix" select="$pix[position() &lt;= $thumbs-per-index]" />
    </xsl:call-template>
    </div>
  	
  	<!-- lister signature -->
    <xsl:call-template name="gal-emit-signature" />
  	
  	</body>
    </html>
    
    <!-- cutter output -->
    <xsl:call-template name="gal-emit-cutter-index">
        <xsl:with-param name="index" select="$index-index" />
        <xsl:with-param name="html-file-prefix" select="$html-file-prefix" />
    </xsl:call-template>
  
    <!-- generate the picture pages -->
    <xsl:call-template name="pages">
        <xsl:with-param name="pix" select="$pix" />
        <xsl:with-param name="parent-index" select="$index-index" />
        <xsl:with-param name="index-last" select="$index-last" />
    </xsl:call-template>
    
</xsl:template>

<xsl:template name="table">
    <xsl:param name="pix" />
    <table class="thumb-table" align="center" cellspacing="10" cellpadding="0" border="0">
        <!-- jump $columns-per-index objects each time and splat
             out the table columns
        -->     
        <xsl:for-each select="$pix[position() mod $columns-per-index = 1]">
            <tr>
            <xsl:call-template name="table-columns-thumbs">
                <xsl:with-param name="pix" select="following-sibling::object[position() &lt; $columns-per-index] | self::object" />
            </xsl:call-template>
            </tr>
            <tr>
            <xsl:call-template name="table-columns-names">
                <xsl:with-param name="pix" select="following-sibling::object[position() &lt; $columns-per-index] | self::object" />
            </xsl:call-template>
            </tr>
        </xsl:for-each>    
    </table>
</xsl:template>

<xsl:template name="table-columns-thumbs">
    <xsl:param name="pix" />
    
    <!-- our job is easy down here. Simply go over all the 
         objects given us and splat them out in their cells
    -->     
    <xsl:for-each select="$pix">
        <td align="center" width="{attrib/thumb-x-size}">
        <a href="{$html-file-prefix}{attrib/name}.html"><img class="thumb" width="{attrib/thumb-x-size}" height="{attrib/thumb-y-size}" src="{attrib/thumb-path}/{attrib/thumb-name}" border="0" /></a>
        </td>
    </xsl:for-each>
</xsl:template>

<xsl:template name="table-columns-names">
    <xsl:param name="pix" />
    
    <!-- our job is easy down here. Simply go over all the 
         objects given us and splat them out in their cells
    -->     
    <xsl:for-each select="$pix">
        <td align="center" valign="top" width="{attrib/thumb-x-size}">
        <a href="{$html-file-prefix}{attrib/name}.html">
        <xsl:value-of select="galleroo:image-title(attrib)" />
        <xsl:value-of select="galleroo:image-caption(attrib)" />
        </a>
        </td>
    </xsl:for-each>
</xsl:template>

<xsl:template name="pages">
    <xsl:param name="pix" />
    <xsl:param name="parent-index" />
    <xsl:param name="index-last" />
        
    <xsl:for-each select="$pix">
        <html>
            <xsl:comment> Transformed from XML with Galleroo Index XSL stylesheet 1.0 </xsl:comment>
            <xsl:comment> Source path='<xsl:value-of select="$source-root/list/media/basepath" />' </xsl:comment>
        <head>
            <title><xsl:value-of select="galleroo:image-title(attrib)" /><xsl:value-of select="galleroo:image-caption(attrib)" /></title>
            <link type="text/css" rel="stylesheet" href="{$html-file-prefix}index.css" />
            <xsl:if test="string-length($custom-css-file) != 0">
                <link type="text/css" rel="stylesheet" href="{$custom-css-file}" />
            </xsl:if>    
        </head>
        <body class="slide-page">

            <!-- title -->
            <div align="center"><h1><xsl:value-of select="$title" /></h1></div>
            
            <!-- navigation bar -->
            <div align="center">      
                <table align="center" border="0">
                <tr>
                    <td> </td>    
 
                    <!-- previous -->
                    <td align="right">
                        <xsl:choose>
                            <xsl:when test="position() = 1 and $parent-index = 1">
                                <img src="{$blank-image}" border="0" />
                            </xsl:when>
                            <xsl:otherwise>
                                <a href="{$html-file-prefix}{galleroo:previous-image()/attrib/name}.html"><img src="{$previous-image}" border="0" /></a>
                            </xsl:otherwise>
                        </xsl:choose>    
                    </td>
                    <!-- home -->
                    <td align="center">
                        <a href="{$html-file-prefix}{galleroo:index-html-name($parent-index)}"><img src="{$home-image}" border="0" /></a>
                    </td>
                   
                    <!-- next -->
                    <td align="left">
                        <xsl:choose>    
                            <xsl:when test="position() = last() and $parent-index = $index-last">
                                <img src="{$blank-image}" border="0" />
                            </xsl:when>
                            <xsl:otherwise>
                               	<a href="{$html-file-prefix}{galleroo:next-image()/attrib/name}.html"><img src="{$next-image}" border="0" /></a>
                            </xsl:otherwise>
                        </xsl:choose>
                    </td>    

                    <td> </td>

                </tr>
                
                <!-- thumbnail slider -->
                <xsl:if test="$do-thumb-slider = 'yes'">
                    <xsl:call-template name="gal-emit-horizontal-thumb-slider">
                        <xsl:with-param name="html-file-prefix" select="$html-file-prefix" />
                        <xsl:with-param name="thumb-size" select="$thumb-size" />
                        <xsl:with-param name="parent-index" select="$parent-index" />
                        <xsl:with-param name="index-last" select="$index-last" />
                    </xsl:call-template>
                </xsl:if>

                </table>
            </div>

            <!-- subtitle -->
            <div align="center">
            <h3><xsl:value-of select="galleroo:image-title(attrib)" /></h3>
            </div>
            
            <!-- comment -->
            <div style="text-align:center; margin-left:auto; margin-right:auto; align:center; width:50%; padding:1em;">
            <xsl:value-of select="galleroo:image-comment(attrib)" />
            </div>
            
            <!-- image -->
            <xsl:call-template name="gal-emit-image">
                <xsl:with-param name="do-auto-play-movies" select="$do-auto-play-movies" />
            </xsl:call-template>
                 
            <!-- download original -->    
            <xsl:if test="boolean(attrib/original-path)">
                <div align="center">
                <a href="{attrib/original-path}/{attrib/name}">Download Original (<xsl:number value="attrib/file-size" /> Bytes)</a>
                
                <!-- commented out pretty number output until xsltproc is fixed.
                    <a href="{attrib/original-path}/{attrib/name}">Download Original (<xsl:number value="attrib/file-size div 1024" grouping-separator="," grouping-size="3" />KB)</a>
                -->    
                </div>
            </xsl:if>

            <!-- lister signature -->
  	        <xsl:call-template name="gal-emit-signature" />
        </body>
        </html>

        <!-- cutter output -->
        <xsl:call-template name="gal-emit-cutter-slide">
            <xsl:with-param name="html-file-prefix" select="$html-file-prefix" />
        </xsl:call-template>
         
    </xsl:for-each>    
</xsl:template>

</xsl:stylesheet>
